==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/UpdateHistoryFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UpdateHistoryFluent<A extends io.fabric8.openshift.api.model.UpdateHistoryFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCompletionTime();
  public A withCompletionTime(java.lang.String completionTime);
  public java.lang.Boolean hasCompletionTime();
  
  /**
   * Method is deprecated. use withCompletionTime instead.
   */
  @java.lang.Deprecated
  public A withNewCompletionTime(java.lang.String arg0);
  public java.lang.String getImage();
  public A withImage(java.lang.String image);
  public java.lang.Boolean hasImage();
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0);
  public java.lang.String getStartedTime();
  public A withStartedTime(java.lang.String startedTime);
  public java.lang.Boolean hasStartedTime();
  
  /**
   * Method is deprecated. use withStartedTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartedTime(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public java.lang.Boolean getVerified();
  public A withVerified(java.lang.Boolean verified);
  public java.lang.Boolean hasVerified();
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/UpdateHistoryFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface UpdateHistoryFluent<A extends io.fabric8.openshift.api.model.UpdateHistoryFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCompletionTime();
  public A withCompletionTime(java.lang.String completionTime);
  public java.lang.Boolean hasCompletionTime();
  
  /**
   * Method is deprecated. use withCompletionTime instead.
   */
  @java.lang.Deprecated
  public A withNewCompletionTime(java.lang.String arg0);
  public java.lang.String getImage();
  public A withImage(java.lang.String image);
  public java.lang.Boolean hasImage();
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0);
  public java.lang.String getStartedTime();
  public A withStartedTime(java.lang.String startedTime);
  public java.lang.Boolean hasStartedTime();
  
  /**
   * Method is deprecated. use withStartedTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartedTime(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public java.lang.Boolean getVerified();
  public A withVerified(java.lang.Boolean verified);
  public java.lang.Boolean hasVerified();
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
